@@ -15,25 +15,26 @@ function(z, cop=NULL, para=NULL, wrtV=FALSE, as.sample=FALSE, verbose=FALSE,
       }
 
       if(as.sample=="genest" | as.sample=="Genest" ) {
-         n <- nrow(para); ns <- 1:n
+         n <- nrow(para); ns <- seq_len(n)
          R <- rank(para[,1]); S <- rank(para[,2])
-         "VIN" <- function(i) sum(as.numeric(R <= R[i] & S <= S[i]))/n
+         "VIN" <- function(i) sum(as.numeric(R <= R[i] & S <= S[i])) / n
          FKin <- sapply(z, function(t) {
-                sum(sapply(ns, function(j) as.numeric(VIN(j) <= t) ))/n })
+                sum(sapply(ns, function(j) as.numeric(VIN(j) <= t) )) / n })
          return(FKin)
       } else if(as.sample == "charpentier" | as.sample == "Charpentier") {
         # Charpentier, Arthur, 2012, Kendall's function for copulas:
         # http://freakonometrics.hypotheses.org/1126  (12/09/2012)
-        n <- nrow(para); i <- rep(ns,each=n); j <- rep(ns,n)
-        S <- (para[i,1] > para[j,1]) & (para[i,2] > para[j,2])
-        Z <- tapply(S,i,sum) / (n-1)
+        n  <- nrow(para);               ns <- seq_len(n)
+        i  <- rep(ns, each=n); j <- rep(ns,n)
+        S  <- (para[i,1] > para[j,1]) & (para[i,2] > para[j,2])
+        Z  <- tapply(S, i, sum) / (n-1)
         zz <- data.frame(t=sort(Z), Kc=(ns)/n)
         return(zz)
       } else {
          n     <- nrow(para)
          FKin  <- sort(EMPIRcop(para[,1], para[,2], para=para, ...))
-         Zin   <- (rank(FKin)-0.5)/n
-         empkc <- approx(c(0,FKin,1), c(0,Zin,1), xout=z)$y
+         Zin   <- ( rank(FKin) - 0.5 ) / n
+         suppressWarnings( empkc <- approx(c(0, FKin, 1), c(0, Zin, 1), xout=z)$y )
          return(empkc)
       }
 
