@@ -1,5 +1,9 @@
 "qua.regressCOP" <-
 function(f=0.5, u=seq(0.01,0.99, by=0.01), cop=NULL, para=NULL, ...) {
+  if(is.null(cop)) {
+     warning("must have copula argument specified, returning NULL")
+     return(NULL)
+  }
   V <- sapply(1:length(u), function(i) {
           v <- derCOPinv(cop=cop, u[i], f, para=para, ...)
           if(is.na(v)) {
